@@ -1,6 +1,6 @@
 import os
 from .file_io import FileIO
-import shutil, os
+from distutils.dir_util import copy_tree
 
 
 
@@ -15,5 +15,5 @@ class Filesystem(FileIO):
         print("Faking upload because it's running locally.")
 
     def download(self, remote_path, local_path, overwrite=True):
-        shutil.copy(remote_path, local_path)
+        copy_tree(remote_path, local_path)
         print("Faking download because it's running locally.")
